@@ -1,5 +1,5 @@
 ## rmatio, a R interface to the C library matio, MAT File I/O Library.
-## Copyright (C) 2013-2018  Stefan Widgren
+## Copyright (C) 2013-2023  Stefan Widgren
 ##
 ## This program is free software: you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 ## You should have received a copy of the GNU General Public License
 ## along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-library("rmatio")
+library(rmatio)
 
 ## For debugging
 sessionInfo()
@@ -28,20 +28,20 @@ sessionInfo()
 ##
 ## complex: case-1
 ##
-a1.exp <- array(complex(real=1:20,imaginary=21:40), c(4,5))
+a1_exp <- array(complex(real = 1:20, imaginary = 21:40), c(4, 5))
 filename <- tempfile(fileext = ".mat")
-write.mat(list(a=a1.exp), filename=filename, compression=FALSE, version='MAT5')
-a1.obs <- read.mat(filename)[['a']]
+write.mat(list(a = a1_exp), filename = filename, compression = FALSE,
+          version = "MAT5")
+a1_obs <- read.mat(filename)[["a"]]
 unlink(filename)
-str(a1.obs)
-stopifnot(identical(a1.obs, a1.exp))
+str(a1_obs)
+stopifnot(identical(a1_obs, a1_exp))
 
 ## Run the same test with compression
-if(rmatio:::have.zlib()) {
-    filename <- tempfile(fileext = ".mat")
-    write.mat(list(a=a1.exp), filename=filename, compression=TRUE, version='MAT5')
-    a1.zlib.obs <- read.mat(filename)[['a']]
-    unlink(filename)
-    str(a1.zlib.obs)
-    stopifnot(identical(a1.zlib.obs, a1.exp))
-}
+filename <- tempfile(fileext = ".mat")
+write.mat(list(a = a1_exp), filename = filename, compression = TRUE,
+          version = "MAT5")
+a1_zlib_obs <- read.mat(filename)[["a"]]
+unlink(filename)
+str(a1_zlib_obs)
+stopifnot(identical(a1_zlib_obs, a1_exp))
